slepc-3.18.0 2022-10-01
Report Typos and Errors

# LMESolve

Solves the linear matrix equation.

### Synopsis

    #include "slepclme.h"
    PetscErrorCode LMESolve(LME lme)

Collective on lme

### Input Parameter

| lme | - linear matrix equation solver context obtained from LMECreate()

### Options Database Keys

| -lme_view | - print information about the solver used
| -lme_view_mat binary | - save the matrix to the default binary viewer
| -lme_view_rhs binary | - save right hand side to the default binary viewer
| -lme_view_solution binary | - save computed solution to the default binary viewer
| -lme_converged_reason | - print reason for convergence, and number of iterations

### Notes

The matrix coefficients are specified with LMESetCoefficients(). The right-hand side is specified with LMESetRHS(). The placeholder for the solution is specified with LMESetSolution().

### See Also

LMECreate(), LMESetUp(), LMEDestroy(), LMESetTolerances(), LMESetCoefficients(), LMESetRHS(), LMESetSolution()

### Level

beginner

### Location

src/lme/interface/lmesolve.c

### Examples

src/lme/tutorials/ex32.c.html
Index of all LME routines
Table of Contents for all manual pages
Index of all manual pages